pub fn print_all()Expand description
Prints a summary of all available commands, grouped by namespace.
This is used when the user uses the help command with no parameters given.
pub fn print_all()Prints a summary of all available commands, grouped by namespace.
This is used when the user uses the help command with no parameters given.